@@ -30,6 +30,9 @@
 #if HAVE_STRING_H
 # include <string.h>
 #endif
+#if HAVE_STRINGS_H
+# include <strings.h>
+#endif
 #if HAVE_STDLIB_H
 # include <stdlib.h>
 #endif
